==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1HorizontalPodAutoscalerStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import org.joda.time.DateTime;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public interface V2beta1HorizontalPodAutoscalerStatusFluent<A extends V2beta1HorizontalPodAutoscalerStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,V2beta1HorizontalPodAutoscalerCondition item);
    public A setToConditions(int index,V2beta1HorizontalPodAutoscalerCondition item);
    public A addToConditions(V2beta1HorizontalPodAutoscalerCondition... items);
    public A addAllToConditions(Collection<V2beta1HorizontalPodAutoscalerCondition> items);
    public A removeFromConditions(V2beta1HorizontalPodAutoscalerCondition... items);
    public A removeAllFromConditions(Collection<V2beta1HorizontalPodAutoscalerCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta1HorizontalPodAutoscalerCondition> getConditions();
    public List<V2beta1HorizontalPodAutoscalerCondition> buildConditions();
    public V2beta1HorizontalPodAutoscalerCondition buildCondition(int index);
    public V2beta1HorizontalPodAutoscalerCondition buildFirstCondition();
    public V2beta1HorizontalPodAutoscalerCondition buildLastCondition();
    public V2beta1HorizontalPodAutoscalerCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerConditionBuilder> predicate);
    public A withConditions(List<V2beta1HorizontalPodAutoscalerCondition> conditions);
    public A withConditions(V2beta1HorizontalPodAutoscalerCondition... conditions);
    public Boolean hasConditions();
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> addNewCondition();
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> addNewConditionLike(V2beta1HorizontalPodAutoscalerCondition item);
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V2beta1HorizontalPodAutoscalerCondition item);
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editCondition(int index);
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editFirstCondition();
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editLastCondition();
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerConditionBuilder> predicate);
    public A addToCurrentMetrics(int index,V2beta1MetricStatus item);
    public A setToCurrentMetrics(int index,V2beta1MetricStatus item);
    public A addToCurrentMetrics(V2beta1MetricStatus... items);
    public A addAllToCurrentMetrics(Collection<V2beta1MetricStatus> items);
    public A removeFromCurrentMetrics(V2beta1MetricStatus... items);
    public A removeAllFromCurrentMetrics(Collection<V2beta1MetricStatus> items);
    
/**
 * This method has been deprecated, please use method buildCurrentMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta1MetricStatus> getCurrentMetrics();
    public List<V2beta1MetricStatus> buildCurrentMetrics();
    public V2beta1MetricStatus buildCurrentMetric(int index);
    public V2beta1MetricStatus buildFirstCurrentMetric();
    public V2beta1MetricStatus buildLastCurrentMetric();
    public V2beta1MetricStatus buildMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricStatusBuilder> predicate);
    public A withCurrentMetrics(List<V2beta1MetricStatus> currentMetrics);
    public A withCurrentMetrics(V2beta1MetricStatus... currentMetrics);
    public Boolean hasCurrentMetrics();
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> addNewCurrentMetric();
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> addNewCurrentMetricLike(V2beta1MetricStatus item);
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> setNewCurrentMetricLike(int index,V2beta1MetricStatus item);
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editCurrentMetric(int index);
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editFirstCurrentMetric();
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editLastCurrentMetric();
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricStatusBuilder> predicate);
    public Integer getCurrentReplicas();
    public A withCurrentReplicas(Integer currentReplicas);
    public Boolean hasCurrentReplicas();
    public A withNewCurrentReplicas(int arg1);
    public A withNewCurrentReplicas(String arg1);
    public Integer getDesiredReplicas();
    public A withDesiredReplicas(Integer desiredReplicas);
    public Boolean hasDesiredReplicas();
    public A withNewDesiredReplicas(int arg1);
    public A withNewDesiredReplicas(String arg1);
    public DateTime getLastScaleTime();
    public A withLastScaleTime(DateTime lastScaleTime);
    public Boolean hasLastScaleTime();
    public A withNewLastScaleTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewLastScaleTime(long arg0);
    public A withNewLastScaleTime(Object arg0);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(String arg1);
    public A withNewObservedGeneration(long arg1);

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1HorizontalPodAutoscalerConditionFluent<V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface CurrentMetricsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1MetricStatusFluent<V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<N>>{

        
    public N and();    public N endCurrentMetric();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1HorizontalPodAutoscalerStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import org.joda.time.DateTime;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public interface V2beta1HorizontalPodAutoscalerStatusFluent<A extends V2beta1HorizontalPodAutoscalerStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,V2beta1HorizontalPodAutoscalerCondition item);
    public A setToConditions(int index,V2beta1HorizontalPodAutoscalerCondition item);
    public A addToConditions(V2beta1HorizontalPodAutoscalerCondition... items);
    public A addAllToConditions(Collection<V2beta1HorizontalPodAutoscalerCondition> items);
    public A removeFromConditions(V2beta1HorizontalPodAutoscalerCondition... items);
    public A removeAllFromConditions(Collection<V2beta1HorizontalPodAutoscalerCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta1HorizontalPodAutoscalerCondition> getConditions();
    public List<V2beta1HorizontalPodAutoscalerCondition> buildConditions();
    public V2beta1HorizontalPodAutoscalerCondition buildCondition(int index);
    public V2beta1HorizontalPodAutoscalerCondition buildFirstCondition();
    public V2beta1HorizontalPodAutoscalerCondition buildLastCondition();
    public V2beta1HorizontalPodAutoscalerCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerConditionBuilder> predicate);
    public A withConditions(List<V2beta1HorizontalPodAutoscalerCondition> conditions);
    public A withConditions(V2beta1HorizontalPodAutoscalerCondition... conditions);
    public Boolean hasConditions();
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> addNewCondition();
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> addNewConditionLike(V2beta1HorizontalPodAutoscalerCondition item);
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V2beta1HorizontalPodAutoscalerCondition item);
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editCondition(int index);
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editFirstCondition();
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editLastCondition();
    public V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerConditionBuilder> predicate);
    public A addToCurrentMetrics(int index,V2beta1MetricStatus item);
    public A setToCurrentMetrics(int index,V2beta1MetricStatus item);
    public A addToCurrentMetrics(V2beta1MetricStatus... items);
    public A addAllToCurrentMetrics(Collection<V2beta1MetricStatus> items);
    public A removeFromCurrentMetrics(V2beta1MetricStatus... items);
    public A removeAllFromCurrentMetrics(Collection<V2beta1MetricStatus> items);
    
/**
 * This method has been deprecated, please use method buildCurrentMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta1MetricStatus> getCurrentMetrics();
    public List<V2beta1MetricStatus> buildCurrentMetrics();
    public V2beta1MetricStatus buildCurrentMetric(int index);
    public V2beta1MetricStatus buildFirstCurrentMetric();
    public V2beta1MetricStatus buildLastCurrentMetric();
    public V2beta1MetricStatus buildMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricStatusBuilder> predicate);
    public Boolean hasMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricStatusBuilder> predicate);
    public A withCurrentMetrics(List<V2beta1MetricStatus> currentMetrics);
    public A withCurrentMetrics(V2beta1MetricStatus... currentMetrics);
    public Boolean hasCurrentMetrics();
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> addNewCurrentMetric();
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> addNewCurrentMetricLike(V2beta1MetricStatus item);
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> setNewCurrentMetricLike(int index,V2beta1MetricStatus item);
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editCurrentMetric(int index);
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editFirstCurrentMetric();
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editLastCurrentMetric();
    public V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<A> editMatchingCurrentMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricStatusBuilder> predicate);
    public Integer getCurrentReplicas();
    public A withCurrentReplicas(Integer currentReplicas);
    public Boolean hasCurrentReplicas();
    public Integer getDesiredReplicas();
    public A withDesiredReplicas(Integer desiredReplicas);
    public Boolean hasDesiredReplicas();
    public DateTime getLastScaleTime();
    public A withLastScaleTime(DateTime lastScaleTime);
    public Boolean hasLastScaleTime();
    public A withNewLastScaleTime(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewLastScaleTime(Object arg0);
    public A withNewLastScaleTime(long arg0);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1HorizontalPodAutoscalerConditionFluent<V2beta1HorizontalPodAutoscalerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface CurrentMetricsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1MetricStatusFluent<V2beta1HorizontalPodAutoscalerStatusFluent.CurrentMetricsNested<N>>{

        
    public N and();    public N endCurrentMetric();
}


}
